@@ -3,9 +3,9 @@
 ##//////////////////////////////////////////////////////////////////////////////
 ##==============================================================================
 ##author: Sebastian Kreutzer
-##organisation: JLU Giessen/Freiberg Instruments
-##version: 0.1.5
-##date: 2014-03-19
+##organisation: IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+##version: 0.1.6
+##date: 2014-09-09
 ##==============================================================================
 
 ##class definition
@@ -50,14 +50,16 @@ setClass("RLum.Analysis",
                 cat("\n\t .. :",names(table(temp)[x]),":",table(temp)[x])
                 
       
-                ##show structure               
-               
+                ##show structure   
+                ##set width option ... just an implementation for the tutorial output
+                ifelse(getOption("width")<=50, temp.width <- 4, temp.width  <- 10)
+                
                 cat("\n\t .. .. : ", 
                     unlist(sapply(1:length(object@records),  function(i) {
                
                       if(names(table(temp)[x]) == is(object@records[[i]])[1]){
                          paste(object@records[[i]]@recordType,
-                         if(i%%10==0 & i!=length(object@records)){"\n\t .. .. : "})
+                         if(i%%temp.width==0 & i!=length(object@records)){"\n\t .. .. : "})
                       }
                     })))
                       
@@ -185,7 +187,7 @@ setMethod("get_RLum.Analysis",
                         keep.object = "ANY"), 
           
           function(object, record.id, recordType, curveType, RLum.type, get.index, keep.object = FALSE){             
-            
+       
             ##record.id
             if(missing(record.id) == TRUE){
               
@@ -193,7 +195,14 @@ setMethod("get_RLum.Analysis",
   
             }else if (is(record.id, "numeric") == FALSE){
               
-              stop("[get_RLum.Analysis] Error: 'record.id' has to be of type 'numeric'!")
+              stop("[get_RLum.Analysis()] 'record.id' has to be of type 'numeric'!")
+              
+            }
+            
+            ##check if record.id exists
+            if(FALSE%in%(abs(record.id)%in%(1:length(object@records)))){
+              
+              stop("[get_RLum.Analysis()] At least one 'record.id' is invalid!")
               
             }
             
@@ -209,7 +218,7 @@ setMethod("get_RLum.Analysis",
               
               if (is(recordType, "character") == FALSE){
               
-                stop("[get_RLum.Analysis] Error: 'recordType' has to be of type 'character'!")
+                stop("[get_RLum.Analysis()] Error: 'recordType' has to be of type 'character'!")
                 
               }
                 
@@ -225,7 +234,7 @@ setMethod("get_RLum.Analysis",
               
             }else if (is(curveType, "character") == FALSE){
               
-              stop("[get_RLum.Analysis] Error: 'curveType' has to be of type 'character'!")
+              stop("[get_RLum.Analysis()] Error: 'curveType' has to be of type 'character'!")
               
             }
             
@@ -236,7 +245,7 @@ setMethod("get_RLum.Analysis",
               
             }else if (is(RLum.type, "character") == FALSE){
               
-              stop("[get_RLum.Analysis] Error: 'RLum.type' has to be of type 'character'!")
+              stop("[get_RLum.Analysis()] Error: 'RLum.type' has to be of type 'character'!")
               
             }
             
@@ -247,16 +256,23 @@ setMethod("get_RLum.Analysis",
               
             }else if (is(get.index, "logical") == FALSE){
               
-              stop("[get_RLum.Analysis] Error: 'get.index' has to be of type 'logical'!")
+              stop("[get_RLum.Analysis()] Error: 'get.index' has to be of type 'logical'!")
               
             }
-            
+    
+             
             
             
            ##-----------------------------------------------------------------##
+           
+           ##a pre-selection is necessary to support negative index selection
+           object@records <- object@records[record.id]
+           record.id <- 1:length(object@records)
+           
+           
            ##select curves according to the chosen paramter
            if(length(record.id)>1){  
-           
+             
             temp <- sapply(record.id, function(x){
              
                 if(is(object@records[[x]])[1]%in%RLum.type == TRUE){
